package
Version:
v0.0.0-...-2428f7e
Opens a new window with list of versions in this module.
Published: Sep 18, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Challenge struct {
DNS string
Servers []string
PropagationWait int
Timeout int
AuthoritativeNssPropagation bool
RecursiveNssPropagation bool
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.